@@ -68,19 +68,24 @@ impl Pile {
         self.0.append(&mut other.0.clone());
     }
 
-    pub fn by_index(&self) -> String {
-        self.by_index_locale(&US_ENGLISH)
+    pub fn to_index(&self) -> String {
+        self.to_index_locale(&US_ENGLISH)
     }
 
-    pub fn by_index_locale(&self, lid: &LanguageIdentifier) -> String {
+    /// https://stackoverflow.com/a/52367953
+    pub fn to_index_str(&self) -> &'static str {
+        Box::leak(self.to_index().into_boxed_str())
+    }
+
+    pub fn to_index_locale(&self, lid: &LanguageIdentifier) -> String {
         Pile::sig_generate_from_strings(&self.collect_index(lid))
     }
 
-    pub fn by_symbol_index(&self) -> String {
-        self.by_symbol_index_locale(&US_ENGLISH)
+    pub fn to_symbol_index(&self) -> String {
+        self.to_symbol_index_locale(&US_ENGLISH)
     }
 
-    pub fn by_symbol_index_locale(&self, lid: &LanguageIdentifier) -> String {
+    pub fn to_symbol_index_locale(&self, lid: &LanguageIdentifier) -> String {
         Pile::sig_generate_from_strings(&self.collect_symbol_index(lid))
     }
 
@@ -126,18 +131,18 @@ impl Pile {
     }
 
     pub fn demo_short(&self) {
-        let langs = &[US_ENGLISH, GERMAN];
+        let languages = &[US_ENGLISH, GERMAN];
 
-        for lang in langs {
+        for lang in languages {
             println!();
             print!("   Short Symbols in {:<5}: ", format!("{}", lang));
-            print!("{}", self.by_symbol_index_locale(lang));
+            print!("{}", self.to_symbol_index_locale(lang));
         }
 
-        for lang in langs {
+        for lang in languages {
             println!();
             print!("   Short Letters in {:<5}: ", format!("{}", lang));
-            print!("{}", self.by_index_locale(lang));
+            print!("{}", self.to_index_locale(lang));
         }
 
         println!();
@@ -440,7 +445,7 @@ impl Default for Pile {
 /// Sets the to_string() function for a Pile to return the default index signature for the Pile.
 impl fmt::Display for Pile {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        let sig = self.by_index();
+        let sig = self.to_index();
         write!(f, "{}", sig)
     }
 }
@@ -796,8 +801,8 @@ mod card_deck_tests {
     fn sig_index() {
         let deck = Pile::spades_deck().draw(4).unwrap();
 
-        let sig_english = deck.by_index();
-        let sig_german = deck.by_index_locale(&GERMAN);
+        let sig_english = deck.to_index();
+        let sig_german = deck.to_index_locale(&GERMAN);
 
         assert_eq!("JBT JLT AS KS".to_string(), sig_english);
         assert_eq!("JGT JKT AS KS".to_string(), sig_german);
@@ -807,7 +812,7 @@ mod card_deck_tests {
     fn sig_symbol_index() {
         let deck = Pile::spades_deck().draw(4).unwrap();
 
-        let sig = deck.by_symbol_index();
+        let sig = deck.to_symbol_index();
 
         assert_eq!("JB🃟 JL🃟 A♠ K♠".to_string(), sig);
     }
